#############################################
# R code - albatross foraging behaviours & success
#############################################

# load libraries that we might need
library(car)
library(dplyr)
library(tibble)
library(bestNormalize)
library(nlme)
library(emmeans)
library(heatmapFit)
library(chisq.posthoc.test)
library(lme4)
library(predictmeans)

# figures/plotting
library(ggplot2)
library(magrittr)
library(ggeffects)
library(sjmisc)
library(splines)
theme_bw.2<-theme_bw() + theme(legend.direction="horizontal", legend.position=c(0.5,1.047), legend.title=element_blank())+theme(title=element_text(size=9.5))

dat <- read.csv(file.choose()) # use dialog box to import data file 
head(dat)
tail(dat)

# Hypotheses. Subordinate species should:
# (H1) have faster response times to food
# (H2) have slower speed
# (H3) have equal success
#       (H3a) pursue smaller pieces of food
# (H4) use peripheral sources of food
# (H5) be less likely to respond to thrown fish in competitive contexts
# (H6) avoid conflict (e.g., scrums)
# (H7) be less likely to respond to another bird with fish

names(dat)

# make sure that all of the factors are treated as factors
dat$spp <- factor(dat$Species, levels = c("bulleri", "salvini", "cauta", "epomophora"))
summary(dat$spp)
dat$date <- as.factor(dat$Date)
summary(dat$date)
dat$success <- as.factor(dat$Success)
summary(dat$success)

# check distribution of continuous variables; transform if different from normal
hist(dat$Response.time) 
symbox(~Response.time, data = dat)
min(dat$Response.time)
dat$tr.response.time <- (dat$Response.time + 3)^0.5 # add 3 to make all values positive; then square root to normalize distribution
hist(dat$tr.response.time)

hist(dat$Speed.cm.s)
symbox(~Speed.cm.s, data = dat)
min(dat$Speed.cm.s)
dat$tr.speed <- log(dat$Speed.cm.s + 1) # add 1 to values to ensure none equal zero; then ln transform (note: 'log' in R is a ln transformation)
hist(dat$tr.speed)

# for H1-H5, use subsetted datasets to examine only birds that responded to fish being thrown
dat.2 <- subset(dat, dat$Behaviour.food != "no.response")

#########################################################
# Statistical tests

###############
# Hypothesis 1. Subordinates have faster responses.

# first test to see if including date/trip as a random factor improves the fit of the model
model1a <- lme(tr.response.time ~ spp, random =~ 1|date, data = dat.2, method = "REML") 
model1b <- gls(tr.response.time ~ spp, data = dat.2, method = "REML") # this model has no random effect
AIC(model1a, model1b) # lower AIC is better; model with random effect performs better

model1 <- lme(tr.response.time ~ spp, random =~ 1|date, data = dat.2, method = "ML") # we could use mixed-effects models, with date as a random factor, but with only two dates at the moment, no need
# check fit of the model to the data
plot(model1)
boxplot(resid(model1) ~ dat.2$spp)
bartlett.test(resid(model1) ~ dat.2$spp)
hist(resid(model1))
shapiro.test(resid(model1))
CookD(model1, newwd="FALSE")
# issue with outlier for epomophora; we'll try running the model without this outlier below

# test the importance of species by comparing model performance with species vs null
model1.null <- lme(tr.response.time ~ 1, random =~ 1|date, data = dat.2, method = "ML") 
anova(model1, model1.null) # model with species as a predictor performs best (lower AIC, significant L.Ratio test)

summary(model1) # summary of model, in R format
emmeans(model1, pairwise~spp, adjust="tukey") # pairwise tests among albatross species

# remove outlier; rerun our model to ensure that results are similar
max(dat.2$Response.time)
hist(dat.2$Response.time)
no.outlier.dat <- subset(dat.2, dat.2$Response.time < 4)
max(no.outlier.dat$Response.time)

# rerunning model with dataset excluding outlier
model1.nout <- lme(tr.response.time ~ spp, random =~ 1|date, data = no.outlier.dat, method = "ML") 
# check fit of the model to the data
plot(model1.nout)
boxplot(resid(model1.nout) ~ no.outlier.dat$spp)
bartlett.test(resid(model1.nout) ~ no.outlier.dat$spp)
hist(resid(model1.nout))
shapiro.test(resid(model1.nout))
CookD(model1.nout, newwd="FALSE")

# test the importance of species by comparing model performance with species vs null
model1.nout.null <- lme(tr.response.time ~ 1, random =~ 1|date, data = no.outlier.dat, method = "ML") # we could use mixed-effects models, with date as a random factor, but with only two dates at the moment, no need
anova(model1.nout, model1.nout.null) # model with species as a predictor performs best (lower AIC, significant L.Ratio test)

summary(model1.nout) # summary of model, in R format
emmeans(model1.nout, pairwise~spp, adjust="tukey") # pairwise tests among albatross species
# similar results to the analysis with the outlier present 

# figure
# raw data plot
response.boxplot <- ggplot(dat.2, aes(y = Response.time, x = spp)) + 
  geom_boxplot(colour="black", fill = "#9FA8DA") +
  labs(x="Species",y="Response time (s)") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
response.boxplot + theme_bw.2

# could use transformed y data - better distribution of points, but harder to interpret
response.boxplot2 <- ggplot(dat.2, aes(y = tr.response.time, x = spp)) + 
  geom_boxplot(colour="black", fill = "#9FA8DA") +
  labs(x="Species",y="Response time (s) \n [(y+3)^0.5] transformed") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
response.boxplot2 + theme_bw.2

# Hypothesis 1, answer: Species differ in their response times; the dominant epomophora 
# is significantly slower to respond than the other three subordinate species.


###############
# Hypothesis 2. Subordinates are slower.

# first test to see if including date/trip as a random factor improves the fit of the model
model2a <- lme(tr.speed ~ spp, random =~ 1|date, data = dat.2, method = "REML") 
model2b <- gls(tr.speed ~ spp, data = dat.2, method = "REML") # this model has no random effect
AIC(model2a, model2b) # lower AIC is better; model with random effect performs better

model2 <- lme(tr.speed ~ spp, random =~ 1|date, data = dat.2, method = "ML") 
# check fit of the model to the data
plot(model2)
boxplot(resid(model2) ~ dat.2$spp)
bartlett.test(resid(model2) ~ dat.2$spp)
hist(resid(model2))
shapiro.test(resid(model2))
CookD(model2, newwd="FALSE")

# test the importance of species by comparing model performance with species vs null
model2.null <- lme(tr.speed ~ 1, random =~ 1|date, data = dat.2, method = "ML") 
anova(model2, model2.null) # model with no predictor (null) performs best (lower AIC)

# figure
# raw data plot
speed.boxplot <- ggplot(dat.2, aes(y = Speed.cm.s, x = spp)) + 
  geom_boxplot(colour="black", fill = "#9FA8DA") +
  labs(x="Species",y="Speed (cm/s)") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
speed.boxplot + theme_bw.2

# could use transformed y data - better distribution of points, but harder to interpret
speed.boxplot2 <- ggplot(dat.2, aes(y = tr.speed, x = spp)) + 
  geom_boxplot(colour="black", fill = "#9FA8DA") +
  labs(x="Species",y="Speed (cm/s) \n [ln(y+1)] transformed") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
speed.boxplot2 + theme_bw.2

# Hypothesis 2, answer: Species did not differ in their speed; subordinate species were not slower.


###############
# Hypothesis 3. Equal success across dominants and subordinates.

# first test to see if including date/trip as a random factor improves the fit of the model
model3a <- glmer(success ~ spp + (1|date), data = dat.2, family = binomial)
model3b <- glm(success ~ spp, data = dat.2, family = binomial) # this model has no random effect
anova(model3a, model3b) # lower AIC is better; model without random effect performs better

model3 <- glm(success ~ spp, family = binomial, data = dat.2)
#check model fit
#don't need to worry about over- or under-dispersion (http://stats.stackexchange.com/questions/92156/how-to-handle-underdispersion-in-glmm-binomial-outcome-variable)
pred<-predict(model3, type="response")
heatmap.fit(model3$y, pred, reps=1000)

# test the importance of species by comparing model performance with species vs null
model3.null <- glm(success ~ 1, family = binomial, data = dat.2)
anova(model3, model3.null, test = "Chi") # can test significance using chi-square test (for binomial families)
AIC(model3, model3.null) # or compare using AIC
# both AIC and chi-square test suggest that model with species performs best

summary(model3) # summary of model, in R format
emmeans(model3, pairwise~spp, adjust="tukey") # pairwise tests among albatross species

# show success/fail (incidence and percentage) for each species
success.food <- table(dat.2$success, dat.2$spp)
addmargins(success.food) # success/fail incidence
round(100*prop.table(success.food, 2), digits=0) # success/fail as percentage

# figure
# model results plot (this will give us error associated with estimate)
success.plot <- ggpredict(model3, "spp [all]") # ggpredict calculates the values that we need from the model
plot(success.plot) # ggpredict plot

# now we'll plot the same results, but with our own specifications
success.pred.plot <- ggplot(success.plot, aes(x=x, y=predicted)) +
  xlab("Species") +
  ylab("Percentage success (95% CI)") +
  scale_x_discrete(limits=c("bulleri", "salvini", "cauta", "epomophora")) +
  geom_point(size = 2) +
  geom_errorbar(aes(ymin=conf.low, ymax=conf.high), width=.1) +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
success.pred.plot + theme_bw.2 

# Hypothesis 3, answer: Species differ in their success when they respond to thrown fish; 
# cauta and bulleri were significantly more successful than the dominant epomophora;
# cauta may also be more successful than salvini (p=0.05)

###############
# Hypothesis 3a. When albatross are successful, do subordinate species acquire smaller pieces of fish?

dat.2a <- subset(dat.2, dat.2$success == "yes")
dat.2a$Size.of.fish <- as.factor(dat.2a$Size.of.fish)
summary(dat.2a$Size.of.fish)
dat.2a$Size.of.fish.ord <- factor(dat.2a$Size.of.fish, order = TRUE, levels = c("piece", "half", "whole"))

library(ordinal) # we are using cumulative link models that can model ordinal responses

# first test to see if including date/trip as a random factor improves the fit of the model
fish.model3a <- clmm(Size.of.fish.ord ~ spp + (1|date), data = dat.2a) 
fish.model3b <- clm(Size.of.fish.ord ~ spp, data = dat.2a)
anova(fish.model3a, fish.model3b) # the simpler model without random effects performs best

fish.model3 <- clm(Size.of.fish.ord ~ spp, data = dat.2a)
summary(fish.model3)
# the condition number of the Hessian (cond.H) is well below 10exp4 - no problem with model fit

# an analysis of deviance (ANODE) table tests the importance of species as a predictor
anova(fish.model3)
emmeans(fish.model3, pairwise~spp, adjust="tukey") # pairwise tests among albatross species
# species was not a significant predictor
# can also compare with null model
fish.model3.null <- clm(Size.of.fish.ord ~ 1, data = dat.2a)
anova(fish.model3, fish.model3.null) # null model performs best

# we can also use a simple chi-square test to test for significant departures from expected
# for the frequencies of different sizes of fish across species (although this is not ordinal)
fish.size <- table(dat.2a$Size.of.fish.ord, dat.2a$spp) # create a frequency table
fishsize.model3 <- chisq.test(fish.size, simulate.p.value=TRUE) # we compute p-values using a Monte Carlo simulation because 25% of the expected values were between 1 and 5
fishsize.model3$expected # all expected numbers should be above one; no more than 20% should be below 5 (25% are below 5, so we simulate the sampling distribution to calculate p values)
fishsize.model3 # significant deviation from expected

# pairwise tests among albatross species
chisq.posthoc.test(fish.size, simulate.p.value=TRUE) # again, we compute p-values using a Monte Carlo simulation because 25% of the expected values were between 1 and 5

# show behaviour frequencies (incidence and percentage) for each species
addmargins(fish.size) # counts
round(100*prop.table(fish.size, 2), digits=0) # percentages

# create a dataframe with percentages for plotting from the table above
x <- c("piece", "half", "whole")
spp <- c("bulleri", "bulleri", "bulleri", "salvini", "salvini", "salvini", "cauta", "cauta", "cauta", "epomophora", "epomophora", "epomophora")
y <- c(63, 5, 32, 25, 25, 50, 37, 31, 31, 38, 25, 38)
plot.fish.size <- data.frame(x, spp, y)
plot.fish.size

# order the species by dominance; order the fish by size
plot.fish.size$spp <- factor(plot.fish.size$spp, levels = c("bulleri", "salvini", "cauta", "epomophora"))
plot.fish.size$x <- factor(plot.fish.size$x, levels = c("piece", "half", "whole"))

# the theme provides information on the layout of the graph and location/details of the legend
theme_bw.3<-theme_bw() + theme(legend.direction="vertical", legend.position=c(0.4, 0.8), legend.title=element_blank())+theme(title=element_text(size=9.5))

fish.size.plot <- ggplot(plot.fish.size, aes(y = y, x = x, fill = spp)) + 
  geom_bar(stat = "identity", color="black", width = 0.7, position=position_dodge()) +
  scale_fill_manual(values=c('#E3F2FD','#64B5F6', '#1E88E5', '#0D47A1')) +
  labs(x="Behaviours", y="Percent frequency") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
fish.size.plot + theme_bw.3

# Hypothesis 3a, answer: No significance differences in the sizes of fish
# obtained by successful albatross across species, although limited
# sample size may obscure differences. T. bulleri tended to take fish pieces more frequently.

###############
# Hypothesis 4. Subordinates will use more peripheral sources of food. 

dat.2$behaviour.food <- as.factor(dat.2$Behaviour.food) # make sure categories are factors
summary(dat.2$behaviour.food)

# we use a simple chi-square test to test for significant departures from expected
# for the frequencies of different behaviours across species
food.behav <- table(dat.2$behaviour.food, dat.2$spp) # create a frequency table
model4 <- chisq.test(food.behav, simulate.p.value=TRUE) # we compute p-values using a Monte Carlo simulation because 25% of the expected values were between 1 and 5
model4$expected # all expected numbers should be above one; no more than 20% should be below 5 (25% are below 5, so we simulate the sampling distribution to calculate p values)
model4 # significant deviation from expected

# pairwise tests among albatross species
chisq.posthoc.test(food.behav, simulate.p.value=TRUE) # again, we compute p-values using a Monte Carlo simulation because 25% of the expected values were between 1 and 5

# show behaviour frequencies (incidence and percentage) for each species
addmargins(food.behav) # counts
round(100*prop.table(food.behav, 2), digits=0) # percentages

# create a dataframe with percentages for plotting from the table above
x <- c("first.to.fish", "peripheral", "pursue")
spp <- c("bulleri", "bulleri", "bulleri", "salvini", "salvini", "salvini", "cauta", "cauta", "cauta", "epomophora", "epomophora", "epomophora")
y <- c(27, 22, 51, 11, 2, 87, 21, 2, 77, 7, 4, 88)
plot.behav.food <- data.frame(x, spp, y)
plot.behav.food

# order the species by dominance
plot.behav.food$spp <- factor(plot.behav.food$spp,levels = c("bulleri", "salvini", "cauta", "epomophora"))

# the theme provides information on the layout of the graph and location/details of the legend
theme_bw.3<-theme_bw() + theme(legend.direction="vertical", legend.position=c(0.2, 0.8), legend.title=element_blank())+theme(title=element_text(size=9.5))

food.behav.plot <- ggplot(plot.behav.food, aes(y = y, x = x, fill = spp)) + 
  geom_bar(stat = "identity", color="black", width = 0.7, position=position_dodge()) +
  scale_fill_manual(values=c('#E3F2FD','#64B5F6', '#1E88E5', '#0D47A1')) +
  labs(x="Behaviours", y="Percent frequency") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
food.behav.plot + theme_bw.3

# Hypothesis 4, answer: Species differ in their behaviours in response to thrown fish; 
# the subordinate bulleri uses significantly more peripheral food and  
# is significantly less likely to pursue the fish

###############
# Hypothesis 5. Subordinates are less likely to respond to food.

# create a new variable describing behaviour towards the food with two levels: response / no.response
dat$behaviour.food <- as.factor(dat$Behaviour.food)
dat$response.food[dat$behaviour.food == "first.to.fish"] <- "response"
dat$response.food[dat$behaviour.food == "peripheral"] <- "response"
dat$response.food[dat$behaviour.food == "pursue"] <- "response"
dat$response.food[dat$behaviour.food == "no.response"] <- "no.response"
dat$response.food <- as.factor(dat$response.food)
summary(dat$response.food)

# first test to see if including date/trip as a random factor improves the fit of the model
model5a <- glmer(response.food ~ spp + (1|date), data = dat, family = binomial)
model5b <- glm(response.food ~ spp, data = dat, family = binomial) # this model has no random effect
anova(model5a, model5b) # lower AIC is better; model without random effect performs better

model5 <- glm(response.food ~ spp, family = binomial, data = dat)
#check model fit
#don't need to worry about over- or under-dispersion (http://stats.stackexchange.com/questions/92156/how-to-handle-underdispersion-in-glmm-binomial-outcome-variable)
pred<-predict(model5, type="response")
heatmap.fit(model5$y, pred, reps=1000)

# test the importance of species by comparing model performance with species vs null
model5.null <- glm(response.food ~ 1, family = binomial, data = dat)
anova(model5, model5.null, test = "Chi") # can test significance using chi-square test (for binomial families)
AIC(model5, model5.null) # or compare using AIC
# both AIC and chi-square test suggest that model with species performs best

summary(model5) # summary of model, in R format
emmeans(model5, pairwise~spp, adjust="tukey") # pairwise tests across albatross species

# show response/no.response (incidence and percentage) for each species
resp.food <- table(dat$response.food, dat$spp)
addmargins(resp.food) # response/no.response incidence
round(100*prop.table(resp.food, 2), digits=0) # response/no.response as percentage

# figure
# model results plot (this will give us error associated with estimate)
food.response.plot <- ggpredict(model5, "spp [all]") # ggpredict calculates the values that we need from the model
plot(food.response.plot) # ggpredict plot

# now we'll plot the same results, but with our own specifications
foodresp.pred.plot <- ggplot(food.response.plot, aes(x=x, y=predicted)) +
  xlab("Species") +
  ylab("Percentage responding to thrown fish (95% CI)") +
  scale_x_discrete(limits=c("bulleri", "salvini", "cauta", "epomophora")) +
  geom_point(size = 2) +
  geom_errorbar(aes(ymin=conf.low, ymax=conf.high), width=.1) +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
foodresp.pred.plot + theme_bw.2 

# Hypothesis 5, answer: Species differ in their tendency to respond to the thrown fish; 
# the subordinate bulleri is significantly less likely to respond to thrown fish than the dominant epomophora

###############
# Hypothesis 6. Subordinates will avoid conflict with the bird who obtained the food.

# remove cases where the focal bird did not respond to the food, or the focal bird obtained the food itself
dat.3 <- subset(dat, dat$Behaviour.bird != "no.response" & dat$Behaviour.bird != "self")

dat.3$behaviour.bird <- as.factor(dat.3$Behaviour.bird) # make sure categories are factors
summary(dat.3$behaviour.bird)

# we use a simple chi-square test to test for significant departures from expected
# for the frequencies of different behaviours across species
bird.behav <- table(dat.3$behaviour.bird, dat.3$spp) # create a frequency table
model6 <- chisq.test(bird.behav, simulate.p.value=TRUE) # we compute p-values using a Monte Carlo simulation because 25% of the expected values were between 1 and 5
model6$expected # all expected numbers should be above one; no more than 20% should be below 5 (25% are below 5, so we simulate the sampling distribution to calculate p values)
model6 # significant deviation from expected

# pairwise tests among albatross species
chisq.posthoc.test(bird.behav, simulate.p.value=TRUE) # again, we compute p-values using a Monte Carlo simulation because 25% of the expected values were between 1 and 5

# show behaviour frequencies (incidence and percentage) for each species
addmargins(bird.behav) # counts
round(100*prop.table(bird.behav, 2), digits=0) # percentages

# create a dataframe with percentages for plotting from the table above
x <- c("avoid.scrum", "open.beak", "chase", "take", "failed.take")
spp <- c("bulleri", "bulleri", "bulleri", "bulleri", "bulleri", "salvini", "salvini", "salvini", "salvini", "salvini", "cauta", "cauta", "cauta", "cauta", "cauta", "epomophora", "epomophora", "epomophora", "epomophora", "epomophora")
y <- c(41, 6, 24, 12, 18, 9, 36, 16, 14, 25, 18, 20, 12, 42, 8, 0, 23, 30, 16, 30)
plot.behav.bird <- data.frame(x, spp, y)
plot.behav.bird

# order the species, behaviours for plotting
plot.behav.bird$spp <- factor(plot.behav.bird$spp, levels = c("bulleri", "salvini", "cauta", "epomophora"))
plot.behav.bird$x <- factor(plot.behav.bird$x, levels = c("avoid.scrum", "chase", "take", "failed.take", "open.beak"))

# the theme provides information on the layout of the graph and location/details of the legend
theme_bw.3<-theme_bw() + theme(legend.direction="vertical", legend.position=c(0.2, 0.8), legend.title=element_blank())+theme(title=element_text(size=9.5))

bird.behav.plot <- ggplot(plot.behav.bird, aes(y = y, x = x, fill = spp)) + 
  geom_bar(stat = "identity", color="black", width = 0.7, position=position_dodge()) +
  scale_fill_manual(values=c('#E3F2FD','#64B5F6', '#1E88E5', '#0D47A1')) +
  labs(x="Behaviours", y="Percent frequency") +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
bird.behav.plot + theme_bw.3

# Hypothesis 6, answer: Species differ in their behaviours in response to the bird that obtains the fish; 
# the subordinate bulleri is significantly more likely to avoid the scrums;
# the dominant epomophora is significantly less likely to avoid the scrums;
# the intermediate cauta is significantly more likely to take fish away, and significantly less likely to have a failed take away attempt



###############
# Hypothesis 7. Subordinates are less likely to respond to the bird that obtains the food.

# [note that we could group these instead into aggressive.response and no.aggressive.response
# where aggressive.response includes chase, open.beak, take, failed.take,
# no.aggressive.response includes no.response, avoid.scrum
# might make more biological sense to take this approach, but creates some overlap with previous H5 test]

dat.4 <- subset(dat, dat$Behaviour.bird != "self") # remove cases where focal bird obtained the fish

# create a new variable describing behaviour towards the bird that obtained the food with two levels: response / no.response
dat.4$behaviour.bird <- as.factor(dat.4$Behaviour.bird)
dat.4$response.birdwithfood[dat.4$behaviour.bird == "avoid.scrum"] <- "response"
dat.4$response.birdwithfood[dat.4$behaviour.bird == "chase"] <- "response"
dat.4$response.birdwithfood[dat.4$behaviour.bird == "failed.take"] <- "response"
dat.4$response.birdwithfood[dat.4$behaviour.bird == "open.beak"] <- "response"
dat.4$response.birdwithfood[dat.4$behaviour.bird == "take"] <- "response"
dat.4$response.birdwithfood[dat.4$behaviour.bird == "no.response"] <- "no.response"
dat.4$response.birdwithfood <- as.factor(dat.4$response.birdwithfood)
summary(dat.4$response.birdwithfood)

# first test to see if including date/trip as a random factor improves the fit of the model
model7a <- glmer(response.birdwithfood ~ spp + (1|date), data = dat.4, family = binomial)
model7b <- glm(response.birdwithfood ~ spp, data = dat.4, family = binomial) # this model has no random effect
anova(model7a, model7b) # lower AIC is better; model without random effect performs better

model7 <- glm(response.birdwithfood ~ spp, family = binomial, data = dat.4)
#check model fit
#don't need to worry about over- or under-dispersion (http://stats.stackexchange.com/questions/92156/how-to-handle-underdispersion-in-glmm-binomial-outcome-variable)
pred<-predict(model7, type="response")
heatmap.fit(model7$y, pred, reps=1000)

# test the importance of species by comparing model performance with species vs null
model7.null <- glm(response.birdwithfood ~ 1, family = binomial, data = dat.4)
anova(model7, model7.null, test = "Chi") # can test significance using chi-square test (for binomial families)
AIC(model7, model7.null) # or compare using AIC
# both AIC and chi-square test suggest that model with species performs best

summary(model7) # summary of model, in R format
emmeans(model7, pairwise~spp, adjust="tukey") # pairwise tests across albatross species

# show response/no.response (incidence and percentage) for each species
resp.birdwithfish <- table(dat.4$response.birdwithfood, dat.4$spp)
addmargins(resp.birdwithfish) # response/no.response incidence
round(100*prop.table(resp.birdwithfish, 2), digits=0) # response/no.response as percentage

# figure
# model results plot (this will give us error associated with estimate)
bird.response.plot <- ggpredict(model7, "spp [all]") # ggpredict calculates the values that we need from the model
plot(bird.response.plot) # ggpredict plot

# now we'll plot the same results, but with our own specifications
birdresp.pred.plot <- ggplot(bird.response.plot, aes(x=x, y=predicted)) +
  xlab("Species") +
  ylab("Percentage responding to another bird with food (95% CI)") +
  scale_x_discrete(limits=c("bulleri", "salvini", "cauta", "epomophora")) +
  geom_point(size = 2) +
  geom_errorbar(aes(ymin=conf.low, ymax=conf.high), width=.1) +
  theme(axis.title.y = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.x = element_text(size = 10,colour="black",face="bold")) +
  theme(axis.title.y = element_text(angle=90,vjust = 0.5))
birdresp.pred.plot + theme_bw.2 

# Hypothesis 7, answer: Species differ in their tendency to respond to the bird that obtained the fish; 
# the subordinate bulleri is significantly less likely to respond to bird that obtained the fish than 
# the other three more dominant species

##############################################
##############################################
